@@ -12,6 +12,18 @@ DEBUG: bool = os.getenv('DEBUG') == '1'
 #: set.
 DEPLOYMENT_ENV: str = os.getenv('DEPLOYMENT_ENV') or 'production'
 
+
+#: Default number of allowed database connections to a single server, if not
+#: otherwise specified.
+DB_MAX_CONNECTIONS = 100
+if 'DB_MAX_CONNECTIONS' in os.environ:
+    DB_MAX_CONNECTIONS = int(os.getenv('DB_MAX_CONNECTIONS'))
+
+#: Default timeout for database connections if not otherwise defined.
+DB_TIMEOUT = 10
+if 'DB_TIMEOUT' in os.environ:
+    DB_TIMEOUT = int(os.getenv('DB_TIMEOUT'))
+
 #: Indicates if SSL should be verified.
 ENABLE_SSL = os.getenv('PYTHONHTTPSVERIFY') != '0'
 
@@ -86,3 +98,11 @@ OAUTH2_TOKEN_EXCHANGE_URL = os.getenv('OAUTH2_TOKEN_EXCHANGE_URL')
 
 #: The default secret key. This is an opaque string.
 SECRET_KEY: str = os.getenv('SECRET_KEY')
+
+# Returns the commit hash of the current application version.
+VCS_COMMIT_HASH = os.getenv('VCS_COMMIT_HASH')
+
+#: Concurrency limit in web environments.
+WEB_CONCURRENCY = None
+if os.getenv('WEB_CONCURRENCY'):
+    WEB_CONCURRENCY = int(os.getenv('WEB_CONCURRENCY'))
