@@ -1,6 +1,8 @@
 """Exposes functions related to HTTP."""
 import urllib.parse
 
+from unimatrix.lib.datastructures import DTO
+
 
 def parse_qs(value):
     """Parses a query string into a dictionary"""
@@ -16,4 +18,4 @@ def parse_qs(value):
 
         params[key] = value
 
-    return params
+    return DTO.fromdict(params)
