@@ -1,8 +1,4 @@
-"""Provides testing helper functions and classes.
-
-.. autoclass:: TestCaseSelector
-    :members:
-"""
+"""Provides testing helper functions and classes."""
 import asyncio
 import functools
 import inspect
@@ -10,6 +6,11 @@ import os
 import types
 import unittest
 
+from unimatrix.lib.environ import parselist
+
+
+__all__ = ['needs']
+
 
 #: The current testing stage as defined by the operating system environment
 #: variable ``TEST_STAGE``.
@@ -29,6 +30,52 @@ TEST_INTEGRATION = 'integration'
 TEST_SYSTEM = 'system'
 
 
+def needs(capabilities):
+    """Return a decorator that skips the test if the required capabilities
+    are not satisfied by the test environment. For a description of
+    allowed values, refer to :envvar:`TEST_STACK_CAPABILITIES`.
+
+    Args:
+        capabilities (list): the list of capabilities required by
+            the decorated test.
+
+    A test can declare its required capabilities with the :func:`needs`
+    decorator. The decorator may be used at the class or at the
+    function level:
+
+    .. code:: python
+
+        class DatabaseTestCase(unittest.TestCase):
+
+            @unimatrix.lib.test.needs('rdbms:postgres')
+            def test_run_on_any_version(self):
+                ... tests
+
+            @unimatrix.lib.test.needs('rdbms:postgres:13')
+            def test_run_on_postgres_13(self):
+                ... tests
+    """
+    if isinstance(capabilities, str):
+        capabilities = [capabilities]
+    required = set(capabilities)
+    provided = parselist(os.environ, 'TEST_STACK_CAPABILITIES', sep=';', cls=set)
+
+    # Quite inefficient
+    for cap in set(provided):
+        for i in range(len(str.split(cap, ':'))):
+            parent = str.join(':', str.rsplit(cap, ':', i+1)[:-i+1])
+            if not parent:
+                break
+            provided.add(parent)
+
+    missing = list(sorted(required - provided))
+    if not missing:
+        return unittest.skipIf(False, "Required capabilities satisfied.")
+
+    return unittest.skipIf(bool(missing),
+        f"Capabilities not satisfied: {','.join(missing)}")
+
+
 class TestCaseSelector:
     """A class, method or function decorator that skips tests based on the
     configured testing environment.
