@@ -1,4 +1,5 @@
 """Provides an API for date and time related functions."""
+import datetime
 import time
 
 
@@ -6,4 +7,4 @@ def now():
     """Return the current date and time, represented as milliseconds since the
     UNIX epoch.
     """
-    return int(time.time() * 1000)
+    return int(datetime.datetime.utcnow().timestamp() * 1000)
